@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2019 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -38,6 +38,12 @@ public:
 	void setSearchMethod(int m);
 	int searchMethod();
 
+	void setUsername(QString username);
+	QString username();
+
+	void setPassword(QString password);
+	QString password();
+
 #ifdef OS_SEARCH_WORKAROUND
 	void setRetries(int n);
 	int retries();
