@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2019 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -838,6 +838,8 @@ void FindSubtitlesWindow::on_configure_button_clicked() {
 	d.setServer( os_server );
 	#endif
 	d.setSearchMethod(osclient->searchMethod());
+	d.setUsername(osclient->username());
+	d.setPassword(osclient->password());
 	#ifdef OS_SEARCH_WORKAROUND
 	d.setRetries(osclient->retries());
 	#endif
@@ -859,6 +861,8 @@ void FindSubtitlesWindow::on_configure_button_clicked() {
 		os_server = d.server();
 		#endif
 		osclient->setSearchMethod( (OSClient::SearchMethod) d.searchMethod() );
+		osclient->setUsername(d.username());
+		osclient->setPassword(d.password());
 		#ifdef OS_SEARCH_WORKAROUND
 		osclient->setRetries( d.retries() );
 		#endif
@@ -934,6 +938,9 @@ void FindSubtitlesWindow::saveSettings() {
 
 	set->setValue("search_method", osclient->searchMethod());
 
+	set->setValue("credentials/username", osclient->username().toUtf8().toBase64());
+	set->setValue("credentials/password", osclient->password().toUtf8().toBase64());
+
 	set->endGroup();
 }
 
@@ -963,6 +970,9 @@ void FindSubtitlesWindow::loadSettings() {
 
 	osclient->setSearchMethod( (OSClient::SearchMethod) set->value("search_method", osclient->searchMethod()).toInt() );
 
+	osclient->setUsername(QString::fromUtf8(QByteArray::fromBase64(set->value("credentials/username", "").toByteArray())));
+	osclient->setPassword(QString::fromUtf8(QByteArray::fromBase64(set->value("credentials/password", "").toByteArray())));
+
 	set->endGroup();
 
 	updateSearchTitleWidget();
