@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2019 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -43,6 +43,7 @@
 #define OSD_PREFIX use_osd_in_commands ? "" : "no-osd"
 //#define OSD_PREFIX ""
 
+
 void MPVProcess::addArgument(const QString & /*a*/) {
 }
 
@@ -125,7 +126,11 @@ void MPVProcess::setFixedOptions() {
 	arg << "--no-quiet";
 	arg << "--terminal";
 	arg << "--no-msg-color";
+#ifdef USE_IPC
+	arg << "--input-ipc-server=" + socket_name;
+#else
 	arg << "--input-file=/dev/stdin";
+#endif
 	//arg << "--no-osc";
 	//arg << "--msg-level=vd=v";
 	//arg << "--video-stereo-mode=no";
@@ -158,6 +163,22 @@ bool MPVProcess::isOptionAvailable(const QString & option) {
 	return option_list.contains(option);
 }
 
+QString MPVProcess::VFDeleteCmd() {
+	QString vf_delete = "del";
+	if (isOptionAvailable("--vf-remove")) {
+		vf_delete = "remove";
+	}
+	return vf_delete;
+}
+
+QString MPVProcess::AFDeleteCmd() {
+	QString af_delete = "del";
+	if (isOptionAvailable("--af-remove")) {
+		af_delete = "remove";
+	}
+	return af_delete;
+}
+
 void MPVProcess::addVFIfAvailable(const QString & vf, const QString & value) {
 	InfoReader * ir = InfoReader::obj(executable());
 	ir->getInfo();
@@ -173,7 +194,7 @@ void MPVProcess::addVFIfAvailable(const QString & vf, const QString & value) {
 
 void MPVProcess::messageFilterNotSupported(const QString & filter_name) {
 	QString text = tr("the '%1' filter is not supported by mpv").arg(filter_name);
-	writeToStdin(QString("show_text \"%1\" 3000").arg(text));
+	sendCommand(QString("show_text \"%1\" 3000").arg(text));
 }
 
 void MPVProcess::enableScreenshots(const QString & dir, const QString & templ, const QString & format) {
@@ -660,9 +681,13 @@ void MPVProcess::setVideoEqualizerOptions(int contrast, int brightness, int hue,
 		#else
 		current_soft_eq = SoftVideoEq(contrast, brightness, hue, saturation, gamma);
 		QString f = videoEqualizerFilter(current_soft_eq);
+		#ifndef USE_FILTER_LABELS
 		arg << "--vf-add=" + f;
 		previous_soft_eq = current_soft_eq;
-		#endif
+		#else
+		arg << "--vf-add=@veq:" + f;
+		#endif // USE_FILTER_LABELS
+		#endif // USE_OLD_VIDEO_EQ
 	}
 #ifndef USE_OLD_VIDEO_EQ
 	else
@@ -688,9 +713,13 @@ void MPVProcess::addAF(const QString & filter_name, const QVariant & value) {
 	if (filter_name == "equalizer") {
 		AudioEqualizerList al = value.toList();
 		QString f = audioEqualizerFilter(al);
+		#ifndef USE_FILTER_LABELS
 		arg << "--af-add=" + f;
 		previous_eq = f;
 		previous_eq_list = al;
+		#else
+		arg << "--af-add=@aeq:" + f;
+		#endif
 	}
 	else {
 		QString s = filter_name;
@@ -700,44 +729,44 @@ void MPVProcess::addAF(const QString & filter_name, const QVariant & value) {
 }
 
 void MPVProcess::quit() {
-	writeToStdin("quit 0");
+	sendCommand("quit 0");
 }
 
 void MPVProcess::setVolume(int v) {
-	writeToStdin("set volume " + QString::number(v));
+	sendCommand("set volume " + QString::number(v));
 }
 
 void MPVProcess::setOSD(int o) {
-	writeToStdin("no-osd set osd-level " + QString::number(o));
+	sendCommand("no-osd set osd-level " + QString::number(o));
 }
 
 void MPVProcess::setAudio(int ID) {
-	writeToStdin(QString("%1 set aid %2").arg(OSD_PREFIX).arg(ID));
+	sendCommand(QString("%1 set aid %2").arg(OSD_PREFIX).arg(ID));
 }
 
 void MPVProcess::setVideo(int ID) {
-	writeToStdin(QString("%1 set vid %2").arg(OSD_PREFIX).arg(ID));
+	sendCommand(QString("%1 set vid %2").arg(OSD_PREFIX).arg(ID));
 }
 
 void MPVProcess::setSubtitle(int type, int ID) {
 	Q_UNUSED(type);
-	writeToStdin(QString("%1 set sid %2").arg(OSD_PREFIX).arg(ID));
+	sendCommand(QString("%1 set sid %2").arg(OSD_PREFIX).arg(ID));
 }
 
 void MPVProcess::disableSubtitles() {
-	writeToStdin("no-osd set sid no");
+	sendCommand("no-osd set sid no");
 }
 
 void MPVProcess::setSecondarySubtitle(int ID) {
-	writeToStdin(QString("%1 set secondary-sid %2").arg(OSD_PREFIX).arg(ID));
+	sendCommand(QString("%1 set secondary-sid %2").arg(OSD_PREFIX).arg(ID));
 }
 
 void MPVProcess::disableSecondarySubtitles() {
-	writeToStdin("no-osd set secondary-sid no");
+	sendCommand("no-osd set secondary-sid no");
 }
 
 void MPVProcess::setSubtitlesVisibility(bool b) {
-	writeToStdin(QString("no-osd set sub-visibility %1").arg(b ? "yes" : "no"));
+	sendCommand(QString("no-osd set sub-visibility %1").arg(b ? "yes" : "no"));
 }
 
 void MPVProcess::seek(double secs, int mode, bool precise) {
@@ -748,29 +777,29 @@ void MPVProcess::seek(double secs, int mode, bool precise) {
 		case 2 : s += "absolute "; break;
 	}
 	if (precise) s += "exact"; else s += "keyframes";
-	writeToStdin(s);
+	sendCommand(s);
 }
 
 void MPVProcess::mute(bool b) {
-	writeToStdin(QString("set mute %1").arg(b ? "yes" : "no"));
+	sendCommand(QString("set mute %1").arg(b ? "yes" : "no"));
 }
 
 void MPVProcess::setPause(bool b) {
-	writeToStdin(QString("set pause %1").arg(b ? "yes" : "no"));
+	sendCommand(QString("set pause %1").arg(b ? "yes" : "no"));
 }
 
 void MPVProcess::frameStep() {
-	writeToStdin("frame_step");
+	sendCommand("frame_step");
 }
 
 void MPVProcess::frameBackStep() {
-	writeToStdin("frame_back_step");
+	sendCommand("frame_back_step");
 }
 
 void MPVProcess::showOSDText(const QString & text, int duration, int level) {
 	if (use_osd_in_commands) {
 		QString str = QString("show_text \"%1\" %2 %3").arg(text).arg(duration).arg(level);
-		writeToStdin(str);
+		sendCommand(str);
 	}
 }
 
@@ -793,7 +822,7 @@ void MPVProcess::showTimeOnOSD() {
 #ifdef OSD_WITH_TIMER
 	osd_timer->stop();
 #endif
-	writeToStdin("show_text \"${time-pos} ${?duration:/ ${duration} (${percent-pos}%)}\" 2000 0");
+	sendCommand("show_text \"${time-pos} ${?duration:/ ${duration} (${percent-pos}%)}\" 2000 0");
 }
 
 #ifdef OSD_WITH_TIMER
@@ -852,7 +881,7 @@ void MPVProcess::setContrast(int value) {
 	}
 	else
 #endif
-	writeToStdin("set contrast " + QString::number(value));
+	sendCommand("set contrast " + QString::number(value));
 }
 
 void MPVProcess::setBrightness(int value) {
@@ -863,7 +892,7 @@ void MPVProcess::setBrightness(int value) {
 	}
 	else
 #endif
-	writeToStdin("set brightness " + QString::number(value));
+	sendCommand("set brightness " + QString::number(value));
 }
 
 void MPVProcess::setHue(int value) {
@@ -874,7 +903,7 @@ void MPVProcess::setHue(int value) {
 	}
 	else
 #endif
-	writeToStdin("set hue " + QString::number(value));
+	sendCommand("set hue " + QString::number(value));
 }
 
 void MPVProcess::setSaturation(int value) {
@@ -885,7 +914,7 @@ void MPVProcess::setSaturation(int value) {
 	}
 	else
 #endif
-	writeToStdin("set saturation " + QString::number(value));
+	sendCommand("set saturation " + QString::number(value));
 }
 
 void MPVProcess::setGamma(int value) {
@@ -896,49 +925,49 @@ void MPVProcess::setGamma(int value) {
 	}
 	else
 #endif
-	writeToStdin("set gamma " + QString::number(value));
+	sendCommand("set gamma " + QString::number(value));
 }
 
 void MPVProcess::setChapter(int ID) {
-	writeToStdin("set chapter " + QString::number(ID));
+	sendCommand("set chapter " + QString::number(ID));
 }
 
 void MPVProcess::nextChapter() {
-	writeToStdin("add chapter 1");
+	sendCommand("add chapter 1");
 }
 
 void MPVProcess::previousChapter() {
-	writeToStdin("add chapter -1");
+	sendCommand("add chapter -1");
 }
 
 void MPVProcess::setExternalSubtitleFile(const QString & filename) {
-	writeToStdin("sub_add \""+ filename +"\"");
-	//writeToStdin("print_text ${track-list}");
-	writeToStdin("print_text \"INFO_TRACKS_COUNT=${=track-list/count}\"");
+	sendCommand("sub_add \""+ filename +"\"");
+	//sendCommand("print_text ${track-list}");
+	sendCommand("print_text \"INFO_TRACKS_COUNT=${=track-list/count}\"");
 }
 
 void MPVProcess::setSubPos(int pos) {
-	writeToStdin("set sub-pos " + QString::number(pos));
+	sendCommand("set sub-pos " + QString::number(pos));
 }
 
 void MPVProcess::setSubScale(double value) {
-	writeToStdin("set sub-scale " + QString::number(value));
+	sendCommand("set sub-scale " + QString::number(value));
 }
 
 void MPVProcess::setSubStep(int value) {
-	writeToStdin("sub_step " + QString::number(value));
+	sendCommand("sub_step " + QString::number(value));
 }
 
 void MPVProcess::seekSub(int value) {
-	writeToStdin("sub-seek " + QString::number(value));
+	sendCommand("sub-seek " + QString::number(value));
 }
 
 void MPVProcess::setSubForcedOnly(bool b) {
-	writeToStdin(QString("set sub-forced-only %1").arg(b ? "yes" : "no"));
+	sendCommand(QString("set sub-forced-only %1").arg(b ? "yes" : "no"));
 }
 
 void MPVProcess::setSpeed(double value) {
-	writeToStdin("set speed " + QString::number(value));
+	sendCommand("set speed " + QString::number(value));
 }
 
 void MPVProcess::enableKaraoke(bool b) {
@@ -966,7 +995,7 @@ void MPVProcess::setAudioEqualizer(AudioEqualizerList l) {
 
 	QStringList commands = AudioEqualizerHelper::equalizerListForCommand(l, previous_eq_list, AudioEqualizerHelper::Anequalizer);
 	foreach(QString command, commands) {
-		writeToStdin("af-command \"anequalizer\" \"change\" \"" + command + "\"");
+		sendCommand("af-command \"anequalizer\" \"change\" \"" + command + "\"");
 	}
 
 	previous_eq_list = l;
@@ -975,7 +1004,7 @@ void MPVProcess::setAudioEqualizer(AudioEqualizerList l) {
 
 	QStringList commands = AudioEqualizerHelper::equalizerListForCommand(l, previous_eq_list, AudioEqualizerHelper::Firequalizer);
 	foreach(QString command, commands) {
-		writeToStdin("af-command \"firequalizer\" \"gain_entry\" \"" + command + "\"");
+		sendCommand("af-command \"firequalizer\" \"gain_entry\" \"" + command + "\"");
 	}
 
 	previous_eq_list = l;
@@ -983,24 +1012,27 @@ void MPVProcess::setAudioEqualizer(AudioEqualizerList l) {
 	#else
 
 	QString eq_filter = audioEqualizerFilter(l);
+	#ifndef USE_FILTER_LABELS
 	if (previous_eq == eq_filter) return;
-
 	if (!previous_eq.isEmpty()) {
-		writeToStdin("af del \"" + previous_eq + "\"");
+		sendCommand("af " + af_delete + " \"" + previous_eq + "\"");
 	}
-
-	writeToStdin("af add \"" + eq_filter + "\"");
+	sendCommand("af add \"" + eq_filter + "\"");
 	previous_eq = eq_filter;
+	#else
+	sendCommand("af " + AFDeleteCmd() + " \"@aeq\"");
+	sendCommand("af add \"@aeq:" + eq_filter + "\"");
+	#endif
 
 #endif
 }
 
 void MPVProcess::setAudioDelay(double delay) {
-	writeToStdin("set audio-delay " + QString::number(delay));
+	sendCommand("set audio-delay " + QString::number(delay));
 }
 
 void MPVProcess::setSubDelay(double delay) {
-	writeToStdin("set sub-delay " + QString::number(delay));
+	sendCommand("set sub-delay " + QString::number(delay));
 }
 
 void MPVProcess::setLoop(int v) {
@@ -1010,24 +1042,24 @@ void MPVProcess::setLoop(int v) {
 		case 0: o = "inf"; break;
 		default: o = QString::number(v);
 	}
-	writeToStdin(QString("set loop-file %1").arg(o));
+	sendCommand(QString("set loop-file %1").arg(o));
 }
 
 void MPVProcess::setAMarker(int sec) {
-	writeToStdin(QString("set ab-loop-a %1").arg(sec));
+	sendCommand(QString("set ab-loop-a %1").arg(sec));
 }
 
 void MPVProcess::setBMarker(int sec) {
-	writeToStdin(QString("set ab-loop-b %1").arg(sec));
+	sendCommand(QString("set ab-loop-b %1").arg(sec));
 }
 
 void MPVProcess::clearABMarkers() {
-	writeToStdin("set ab-loop-a no");
-	writeToStdin("set ab-loop-b no");
+	sendCommand("set ab-loop-a no");
+	sendCommand("set ab-loop-b no");
 }
 
 void MPVProcess::takeScreenshot(ScreenshotType t, bool include_subtitles) {
-	writeToStdin(QString("screenshot %1 %2").arg(include_subtitles ? "subtitles" : "video").arg(t == Single ? "single" : "each-frame"));
+	sendCommand(QString("screenshot %1 %2").arg(include_subtitles ? "subtitles" : "video").arg(t == Single ? "single" : "each-frame"));
 }
 
 #ifdef CAPTURE_STREAM
@@ -1039,9 +1071,9 @@ void MPVProcess::switchCapturing() {
 			// I hate Windows
 			f = f.replace("\\", "\\\\");
 			#endif
-			writeToStdin("set stream-capture \"" + f + "\"");
+			sendCommand("set stream-capture \"" + f + "\"");
 		} else {
-			writeToStdin("set stream-capture \"\"");
+			sendCommand("set stream-capture \"\"");
 		}
 		capturing = !capturing;
 	}
@@ -1049,34 +1081,34 @@ void MPVProcess::switchCapturing() {
 #endif
 
 void MPVProcess::setTitle(int ID) {
-	writeToStdin("set disc-title " + QString::number(ID));
+	sendCommand("set disc-title " + QString::number(ID));
 }
 
 #if DVDNAV_SUPPORT
 void MPVProcess::discSetMousePos(int x, int y) {
 	qDebug("MPVProcess::discSetMousePos: %d %d", x, y);
-	//writeToStdin(QString("discnav mouse_move %1 %2").arg(x).arg(y));
+	//sendCommand(QString("discnav mouse_move %1 %2").arg(x).arg(y));
 	// mouse_move doesn't accept options :?
 
 	// For some reason this doesn't work either...
 	// So it's not possible to select options in the dvd menus just
 	// because there's no way to pass the mouse position to mpv, or it
 	// ignores it.
-	writeToStdin(QString("mouse %1 %2").arg(x).arg(y));
-	//writeToStdin("discnav mouse_move");
+	sendCommand(QString("mouse %1 %2").arg(x).arg(y));
+	//sendCommand("discnav mouse_move");
 }
 
 void MPVProcess::discButtonPressed(const QString & button_name) {
-	writeToStdin("discnav " + button_name);
+	sendCommand("discnav " + button_name);
 }
 #endif
 
 void MPVProcess::setAspect(double aspect) {
-	writeToStdin("set video-aspect " + QString::number(aspect));
+	sendCommand("set video-aspect " + QString::number(aspect));
 }
 
 void MPVProcess::setFullscreen(bool b) {
-	writeToStdin(QString("set fullscreen %1").arg(b ? "yes" : "no"));
+	sendCommand(QString("set fullscreen %1").arg(b ? "yes" : "no"));
 }
 
 #if PROGRAM_SWITCH
@@ -1086,19 +1118,19 @@ void MPVProcess::setTSProgram(int ID) {
 #endif
 
 void MPVProcess::toggleDeinterlace() {
-	writeToStdin("cycle deinterlace");
+	sendCommand("cycle deinterlace");
 }
 
 void MPVProcess::askForLength() {
-	writeToStdin("print_text \"INFO_LENGTH=${=length}\"");
+	sendCommand("print_text \"INFO_LENGTH=${=length}\"");
 }
 
 void MPVProcess::setOSDScale(double value) {
-	writeToStdin("set osd-scale " + QString::number(value));
+	sendCommand("set osd-scale " + QString::number(value));
 }
 
 void MPVProcess::setOSDFractions(bool active) {
-	writeToStdin(QString("no-osd set osd-fractions %1").arg(active ? "yes" : "no"));
+	sendCommand(QString("no-osd set osd-fractions %1").arg(active ? "yes" : "no"));
 }
 
 void MPVProcess::changeVF(const QString & filter, bool enable, const QVariant & option) {
@@ -1125,7 +1157,7 @@ void MPVProcess::changeVF(const QString & filter, bool enable, const QVariant &
 	}
 
 	if (!f.isEmpty()) {
-		writeToStdin(QString("vf %1 \"%2\"").arg(enable ? "add" : "del").arg(f));
+		sendCommand(QString("vf %1 \"%2\"").arg(enable ? "add" : VFDeleteCmd()).arg(f));
 	}
 }
 
@@ -1140,7 +1172,7 @@ void MPVProcess::changeAF(const QString & filter, bool enable, const QVariant &
 	}
 
 	if (!f.isEmpty()) {
-		writeToStdin(QString("af %1 \"%2\"").arg(enable ? "add" : "del").arg(f));
+		sendCommand(QString("af %1 \"%2\"").arg(enable ? "add" : AFDeleteCmd()).arg(f));
 	}
 }
 
@@ -1152,7 +1184,7 @@ void MPVProcess::changeStereo3DFilter(bool enable, const QString & in, const QSt
 	if (!out.isEmpty()) output = "out=" + out;
 
 	QString filter = "lavfi=[stereo3d=" + input + output + "]";
-	writeToStdin(QString("vf %1 \"%2\"").arg(enable ? "add" : "del").arg(filter));
+	sendCommand(QString("vf %1 \"%2\"").arg(enable ? "add" : VFDeleteCmd()).arg(filter));
 }
 
 #if 0
@@ -1460,12 +1492,16 @@ QString MPVProcess::videoEqualizerFilter(SoftVideoEq eq) {
 }
 
 void MPVProcess::updateSoftVideoEqualizerFilter() {
+	#ifndef USE_FILTER_LABELS
 	QString f = videoEqualizerFilter(previous_soft_eq);
-	writeToStdin("vf del \"" + f + "\"");
-
+	sendCommand("vf " + vf_delete + " \"" + f + "\"");
 	f = videoEqualizerFilter(current_soft_eq);
-	writeToStdin("vf add \"" + f + "\"");
-
+	sendCommand("vf add \"" + f + "\"");
 	previous_soft_eq = current_soft_eq;
+	#else
+	sendCommand("vf " + VFDeleteCmd() + " \"@veq\"");
+	QString f = videoEqualizerFilter(current_soft_eq);
+	sendCommand("vf add \"@veq:" + f + "\"");
+	#endif
 }
 #endif
