@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2019 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,6 +27,18 @@
 #include "mplayerversion.h"
 #include "colorutils.h"
 
+#ifdef USE_IPC
+#include <QLocalSocket>
+#endif
+
+#ifdef USE_IPC
+ #if QT_VERSION >= 0x050000
+ #include <QStandardPaths>
+ #else
+ #include <QDesktopServices>
+ #endif
+#endif
+
 using namespace Global;
 
 #define CUSTOM_STATUS
@@ -75,9 +87,25 @@ MPVProcess::MPVProcess(QObject * parent)
 
 	initializeOptionVars();
 	initializeRX();
+
+#ifdef USE_IPC
+	socket = new QLocalSocket(this);
+	#if QT_VERSION >= 0x050000
+	QString temp_dir = QStandardPaths::writableLocation(QStandardPaths::TempLocation);
+	#else
+	QString temp_dir = QDesktopServices::storageLocation(QDesktopServices::TempLocation);
+	#endif
+	socket_name = temp_dir + "/smplayer-mpv-" + QString::number(QCoreApplication::applicationPid(), 16);
+	qDebug() << "MPVProcess::MPVProcess: socket_name:" << socket_name;
+#endif
 }
 
 MPVProcess::~MPVProcess() {
+#ifdef USE_IPC
+	if (QFile::exists(socket_name)) {
+		QFile::remove(socket_name);
+	}
+#endif
 }
 
 bool MPVProcess::start() {
@@ -419,7 +447,7 @@ void MPVProcess::parseLine(QByteArray ba) {
 		if (rx_vo.indexIn(line) > -1) {
 			emit receivedVO( rx_vo.cap(1) );
 			// Ask for window resolution
-			writeToStdin("print_text INFO_VIDEO_DSIZE=${=dwidth}x${=dheight}");
+			sendCommand("print_text INFO_VIDEO_DSIZE=${=dwidth}x${=dheight}");
 		}
 		else
 		
@@ -678,7 +706,7 @@ void MPVProcess::parseLine(QByteArray ba) {
 				}
 				#endif
 				for (int n = 0; n < md.n_chapters; n++) {
-					writeToStdin(QString("print_text INFO_CHAPTER_%1_NAME=${chapter-list/%1/title}").arg(n));
+					sendCommand(QString("print_text INFO_CHAPTER_%1_NAME=${chapter-list/%1/title}").arg(n));
 				}
 			}
 			else
@@ -743,7 +771,7 @@ void MPVProcess::parseLine(QByteArray ba) {
 			if (tag == "INFO_TRACKS_COUNT") {
 				int tracks = value.toInt();
 				for (int n = 0; n < tracks; n++) {
-					writeToStdin(QString("print_text \"INFO_TRACK_%1: "
+					sendCommand(QString("print_text \"INFO_TRACK_%1: "
 						"${track-list/%1/type} "
 						"${track-list/%1/id} "
 						"'${track-list/%1/lang:}' "
@@ -757,13 +785,13 @@ void MPVProcess::parseLine(QByteArray ba) {
 }
 
 void MPVProcess::requestChapterInfo() {
-	writeToStdin("print_text \"INFO_CHAPTERS=${=chapters}\"");
+	sendCommand("print_text \"INFO_CHAPTERS=${=chapters}\"");
 }
 
 /*
 void MPVProcess::requestBitrateInfo() {
-	writeToStdin("print_text INFO_VIDEO_BITRATE=${=video-bitrate}");
-	writeToStdin("print_text INFO_AUDIO_BITRATE=${=audio-bitrate}");
+	sendCommand("print_text INFO_VIDEO_BITRATE=${=video-bitrate}");
+	sendCommand("print_text INFO_AUDIO_BITRATE=${=audio-bitrate}");
 }
 */
 
@@ -867,5 +895,27 @@ void MPVProcess::gotError(QProcess::ProcessError error) {
 	qDebug("MPVProcess::gotError: %d", (int) error);
 }
 
+#ifdef USE_IPC
+void MPVProcess::sendCommand(QString text) {
+	qDebug() << "MPVProcess::sendCommand:" << text;
+
+	if (!isRunning()) {
+		qWarning("MPVProcess::sendCommand: mpv is not running. Command ignored.");
+		return;
+	}
+
+	if (socket->state() != QLocalSocket::ConnectedState) {
+		qDebug() << "MPVProcess::sendCommand: state:" << socket->state();
+		qDebug() << "MPVProcess::sendCommand: error:" << socket->errorString();
+		socket->close();
+		socket->connectToServer(socket_name, QIODevice::ReadWrite | QIODevice::Text);
+		socket->waitForConnected();
+		qDebug() << "MPVProcess::sendCommand: state:" << socket->state();
+	}
+	socket->write(text.toUtf8() +"\n");
+	socket->flush();
+}
+#endif
+
 #include "mpvoptions.cpp"
 #include "moc_mpvprocess.cpp"
