@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2019 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2020 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,6 +27,10 @@
 #define OSD_WITH_TIMER
 //#define USE_OLD_VIDEO_EQ
 
+#define USE_FILTER_LABELS
+
+#define USE_IPC
+
 #ifndef USE_OLD_VIDEO_EQ
 class SoftVideoEq
 {
@@ -40,6 +44,7 @@ public:
 #endif
 
 class QStringList;
+class QLocalSocket;
 
 class MPVProcess : public PlayerProcess
 {
@@ -51,6 +56,10 @@ public:
 
 	bool start();
 
+#ifdef USE_IPC
+	virtual void sendCommand(QString text);
+#endif
+
 	// Command line options
 	void addArgument(const QString & a);
 	void setMedia(const QString & media, bool is_playlist = false);
@@ -158,6 +167,9 @@ protected:
 	void toggleInfoOnOSD();
 #endif
 
+	QString VFDeleteCmd();
+	QString AFDeleteCmd();
+
 protected slots:
 	void parseLine(QByteArray ba);
 	void processFinished(int exitCode, QProcess::ExitStatus exitStatus);
@@ -245,13 +257,17 @@ private:
 	int dvd_current_title;
 	int br_current_title;
 
+	#ifndef USE_FILTER_LABELS
 	QString previous_eq;
 	AudioEqualizerList previous_eq_list;
+	#endif
 
 #ifndef USE_OLD_VIDEO_EQ
 	bool use_soft_eq;
 	SoftVideoEq current_soft_eq;
+	#ifndef USE_FILTER_LABELS
 	SoftVideoEq previous_soft_eq;
+	#endif
 #endif
 
 #ifdef CAPTURE_STREAM
@@ -296,6 +312,11 @@ private:
 	QRegExp rx_debug;
 
 	void initializeRX();
+
+#ifdef USE_IPC
+	QLocalSocket * socket;
+	QString socket_name;
+#endif
 };
 
 #endif
